TODO
====
- Improved workflow documentation with example data
- Extend [translate] to support more tags (e.g. GT)
- Extend [merge] to filter and disambiguate tag collisions
- Add [weave] command to combine [translate, merge, summarize]
- Extend [expand] to parse SnpEff/Annovar annotated results
- Extend [expand] to generate formatted results
- Improve command validation (check source tags, check "shape" of inputs)
- Enable 4.2 VCF support
- Add support for new somatic callers
- Add support for Germline workflows
- Add support for Galaxy integration
- Add gene-level rollup for annotated data
